//----------------------------------------------------------------------
//  Author: Thomas S. Ullrich (Feb 2005)
//
//  This file is part of hxBrowser.
//  
//  Description: Definition of the hxCanvas class
//----------------------------------------------------------------------
#ifndef hxCanvas_h
#define hxCanvas_h

#include <qgl.h>
#include <vector>
#include "StThreeVector.h"

class StPhysicalHelix;

class hxCanvas :  public QGLWidget
{ 
    Q_OBJECT  
public:
    hxCanvas(QWidget*, const char*);
    ~hxCanvas();    

    void setHelix(StPhysicalHelix*);
    void displayDCAToPoint(StThreeVector<>&, bool);
    void displayIntersectionWithCylinder(double, double, double);
    void removeDCAToPointDisplay();
    void removeIntersectionWithCylinderDisplay();

public slots:
    void rotateX(int);
    void rotateY(int);
    void rotateZ(int);
    void setShowTpcFrame(bool);
    void setShowBeamPipe(bool);
    void setShowAxis(bool);
    void resetZoomAndShift();

protected:
    void initializeGL();
    void resizeGL(int, int);
    void paintGL();
    void draw();
    void drawHelix();
    void drawTpcFrame();
    void drawBeamPipe();
    void drawAxis();
    void drawText(double, double, double, char*, double);
    void keyPressEvent(QKeyEvent*);
    void mouseMoveEvent(QMouseEvent*);
    void mousePressEvent(QMouseEvent*);
    void mouseReleaseEvent(QMouseEvent*);
    void wheelEvent(QWheelEvent*);

protected:
    enum {tpc, beampipe, axis, helix, dca, cylinder, last};
    static vector<size_t>  mDisplayLists;
    GLdouble mWCSizeX;
    GLdouble mWCSizeY;
    GLdouble mWCSizeZ;
    GLdouble mRotationX;
    GLdouble mRotationY;
    GLdouble mRotationZ;
    GLdouble mTranslateX;
    GLdouble mTranslateY;
    GLdouble mTranslateZ;
    GLdouble mScale;
    bool mShowTpcFrame;
    bool mShowBeamPipe;
    bool mShowAxis;
    bool mShowDCA;
    bool mShowCylinder;
    QPoint mLastMousePosition;
    StPhysicalHelix *mHelix;
};
#endif
