//----------------------------------------------------------------------
//  Author: Thomas S. Ullrich (Feb 2005)
//
//  This file is part of hxBrowser.
//  
//  Description: Implementation of hxHelpBrowser class
//----------------------------------------------------------------------
#include <qapplication.h>
#include <qdir.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qtextbrowser.h>
#include <qmessagebox.h>
#include "hxHelpBrowser.h"

hxHelpBrowser::hxHelpBrowser(const QString &path, const QString &page,
                             QWidget *parent, const char *name)
                             : QWidget(parent, name, WGroupLeader|WDestructiveClose)
{
    mTextBrowser = new QTextBrowser(this);
    mHomeButton  = new QPushButton(tr("&Home"), this);
    mBackButton  = new QPushButton(tr("&Back"), this);
    mCloseButton = new QPushButton(tr("&Close"), this);
    mCloseButton->setAccel(tr("Esc"));

    QVBoxLayout *mainLayout = new QVBoxLayout(this);
    mainLayout->setMargin(3);

    QHBoxLayout *buttonLayout = new QHBoxLayout(mainLayout);
    buttonLayout->setMargin(3);
    buttonLayout->addWidget(mHomeButton);
    buttonLayout->addWidget(mBackButton);
    buttonLayout->addStretch(3); 
    buttonLayout->addWidget(mCloseButton);
    mainLayout->addWidget(mTextBrowser);

    connect(mHomeButton, SIGNAL(clicked()), mTextBrowser, SLOT(home()));
    connect(mBackButton, SIGNAL(clicked()), mTextBrowser, SLOT(backward()));
    connect(mCloseButton, SIGNAL(clicked()), this, SLOT(close()));
    connect(mTextBrowser, SIGNAL(sourceChanged(const QString &)), this, SLOT(updateCaption()));

    mTextBrowser->mimeSourceFactory()->addFilePath(path);
    mTextBrowser->setSource(page);
}

void hxHelpBrowser::updateCaption()
{
    setCaption(tr("Help: %1").arg(mTextBrowser->documentTitle()));
}

void hxHelpBrowser::showPage(const QString &page)
{
    QString path = qApp->applicationDirPath() + "/doc";
    QDir dir(path);
    if (!dir.exists()) { 
        path = qApp->applicationDirPath() + "/../doc";
        dir.setPath(path);
    }
    if (!dir.exists()) {
          QMessageBox::warning( 0, "hxBrowser",
              "Cannot find the directory holding the documentation (doc).\n"
              "hxBrowser will still run but you won't be able to use the\n"
              "help utility. Ceck your installation and reinstall if necessary.");
    }
    hxHelpBrowser *browser = new hxHelpBrowser(path, page);
    browser->resize(700,450);
    browser->show();
}

