//----------------------------------------------------------------------
//  Author: Thomas S. Ullrich (Feb 2005)
//
//  This file is part of hxBrowser.
//  
//  Description: Definition of the hxParameter and hxSettings class
//----------------------------------------------------------------------
#ifndef hxSettings_h
#define hxSettings_h

#include <typeinfo>
#include <qstring.h>
#include <qlistview.h>

template<class T = double> class hxParameter {
public:
    hxParameter(QString = "", QListViewItem* = 0, T = 0);

    QString& description();
    QListViewItem* listViewItem();
    T value();
    QString svalue();

    void updateFromItem();
    void restoreToItem();

    void setDescription(QString);
    void setListViewItem(QListViewItem*);
    void setValue(T);

private:
    QString         mDescription;
    QListViewItem   *mItem;
    T               mValue;
};

template<class T> inline hxParameter<T>::hxParameter(QString txt, QListViewItem* item, T val)
{
    mDescription = txt;
    mItem = item;
    mValue = val;
}

template<class T> inline void hxParameter<T>::setDescription(QString txt) {mDescription = txt;}
template<class T> inline void hxParameter<T>::setListViewItem(QListViewItem* item) {mItem = item;}
template<class T> inline void hxParameter<T>::setValue(T val) {mValue = val;}
template<class T> inline QString& hxParameter<T>::description() {return mDescription;}
template<class T> inline QListViewItem* hxParameter<T>::listViewItem() {return mItem;}
template<class T> inline T hxParameter<T>::value() {return mValue;}

template<class T> inline QString hxParameter<T>::svalue() 
{
    QString txt;
    if (typeid(mValue) == typeid(bool))
        txt = mValue ? "true" : "false";
    else
        txt.setNum(mValue);
    return txt;
}

template<class T> inline void hxParameter<T>::updateFromItem()
{
    if (mItem) {
        bool Ok = true;
        QString txt = mItem->text(2);
        T val;
        if (typeid(val) == typeid(int))
            val = txt.toInt(&Ok);
        else if (typeid(val) == typeid(bool) ) {
            txt = txt.lower();
            val = (txt == "true" || txt == "1" || txt == "t" || txt == "on");
        }
        else
            val = txt.toDouble(&Ok);
            
        if (Ok) mValue = val;
        mItem->setText(1,svalue());
        mItem->setText(2,svalue());
    }
}
 
template<class T> inline void hxParameter<T>::restoreToItem()
{
    if (mItem)
        mItem->setText(2,svalue()); 
}

class hxSettings
{
public:
    static hxSettings* instance();

    hxParameter<double> mMaxRForHelixDrawing;
    hxParameter<double> mMaxZForHelixDrawing;
    hxParameter<double> mHelixDrawingSegmentSize;
    hxParameter<double> mMaxHelixLength;

    hxParameter<double> m3DPointSegmentLength;

    hxParameter<double> mCylinderLength;
    hxParameter<int>    mNumberOfCylinderSlices;
    hxParameter<int>    mNumberOfCylinderStacks;

    hxParameter<bool>   mAnglesInDegree;

protected:
    hxSettings();

private:
    static hxSettings* mInstance;

};
#endif
