//----------------------------------------------------------------------
//  Author: Thomas S. Ullrich (Feb 2005)
//
//  This file is part of hxBrowser.
//  
//  Description: Implementation of hxSettingsDialog class
//----------------------------------------------------------------------
#include <qapplication.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include "hxSettingsDialog.h"
#include "hxMainWindowImp.h"

hxSettingsDialog::hxSettingsDialog(QWidget *parent, const char *name, bool modal)
: QDialog (parent, name, modal)
{
    mListView = new QListView(this);
    mListView->addColumn(tr("Parameter"));
    mListView->addColumn(tr("Current Value"));
    mListView->addColumn(tr("New Value"));
    mListView->setRootIsDecorated(true);
    mListView->setDefaultRenameAction(QListView::Accept);
    mListView->setItemMargin(2);

    QListViewItem *item1 = new QListViewItem(mListView, "Drawings"); 
    QListViewItem *item2 = new QListViewItem(mListView, "Helix Parameter"); 
    item1->setOpen(true);
    item2->setOpen(true);

    QListViewItem *item1sub1 = new QListViewItem(item1, "Helix"); 
    QListViewItem *item1sub2 = new QListViewItem(item1, "Point and DCA"); 
    QListViewItem *item1sub3 = new QListViewItem(item1, "Cylinder and Intersection Points"); 
    QListViewItem *item2sub1 = new QListViewItem(item2, "Units"); 


    hxSettings *settings = hxSettings::instance();
    setupChangableItem(settings->mMaxHelixLength, item1sub1);
    setupChangableItem(settings->mHelixDrawingSegmentSize, item1sub1);
    setupChangableItem(settings->mMaxZForHelixDrawing, item1sub1);
    setupChangableItem(settings->mMaxRForHelixDrawing, item1sub1);

    setupChangableItem(settings->m3DPointSegmentLength, item1sub2);

    setupChangableItem(settings->mCylinderLength, item1sub3);
    setupChangableItem(settings->mNumberOfCylinderSlices, item1sub3);
    setupChangableItem(settings->mNumberOfCylinderStacks, item1sub3);

    setupChangableItem(settings->mAnglesInDegree, item2sub1);

    mOkButton  = new QPushButton(tr("&Ok"), this);
    mCancelButton  = new QPushButton(tr("&Cancel"), this);

    QVBoxLayout *mainLayout = new QVBoxLayout(this);
    mainLayout->setMargin(3);
    mainLayout->addWidget(mListView);
    QHBoxLayout *buttonLayout = new QHBoxLayout(mainLayout);
    buttonLayout->setMargin(3);
    buttonLayout->addWidget(mOkButton);
    buttonLayout->addStretch(1); 
    buttonLayout->addWidget(mCancelButton);

    connect(mCancelButton, SIGNAL(clicked()), this, SLOT(restoreAndClose()));
    connect(mOkButton, SIGNAL(clicked()), this, SLOT(applyAndClose()));
    resize(600, 300);

    setCaption("hxBrowser Settings");
}

void hxSettingsDialog::applyAndClose()
{
    hxSettings *settings = hxSettings::instance();
    settings->mMaxRForHelixDrawing.updateFromItem();
    settings->mMaxZForHelixDrawing.updateFromItem();
    settings->mHelixDrawingSegmentSize.updateFromItem();
    settings->mMaxHelixLength.updateFromItem();
    settings->m3DPointSegmentLength.updateFromItem();
    settings->mCylinderLength.updateFromItem();
    settings->mNumberOfCylinderSlices.updateFromItem();
    settings->mNumberOfCylinderStacks.updateFromItem();
    settings->mAnglesInDegree.updateFromItem();

    hxMainWindowImp *win = dynamic_cast<hxMainWindowImp*>(this->parent());
    if (win) win->syncWithSettings();

    close();
}

void hxSettingsDialog::restoreAndClose()
{
    hxSettings *settings = hxSettings::instance();
    settings->mMaxRForHelixDrawing.restoreToItem();
    settings->mMaxZForHelixDrawing.restoreToItem();
    settings->mHelixDrawingSegmentSize.restoreToItem();
    settings->mMaxHelixLength.restoreToItem();
    settings->m3DPointSegmentLength.restoreToItem();
    settings->mCylinderLength.restoreToItem();
    settings->mNumberOfCylinderSlices.restoreToItem();
    settings->mNumberOfCylinderStacks.restoreToItem();
    settings->mAnglesInDegree.restoreToItem();
    close();
}